==> qiho-center-api-2.5.34-20200723.021841-22-sources.jar: com/qiho/center/api/dto/merchant/MerchantDto.java <==
package com.qiho.center.api.dto.merchant;/**
 * Created by Administrator on 2017/11/15 0015.
 */

import com.qiho.center.api.dto.BaseDto;

import java.util.Date;

/** 商家实体
 * @author chensong
 * @create 2017-11-15 11:23
 **/
public class MerchantDto extends BaseDto{

    /** 主键Id */
    private Long id;

    /** 商家名称 */
    private String merchantName;

    /** 联系人姓名 */
    private String contactName;

    /** 联系方式 */
    private String contactMobile;

    /** 联系地址 */
    private String address;

    /** 邮箱 */
    private String email;

    /** 发货方式 */
    private String delivery;

    /** 客服姓名 */
    private String customerServiceName;

    /** 客服联系方式 */
    private String customerServiceMobile;

    /** 备注 */
    private String remark;

    /** 权重，排序值 */
    private Integer payload;

    /** 删除标识，true-删除/false-未删除 */
    private Boolean deleted;

    /** 创建人ID */
    private Long gmtCreator;

    /** 修改人ID */
    private Long gmtModifier;

    /** 创建时间 */
    private Date gmtCreate;

    /** 修改时间 */
    private Date gmtModified;

    /** 商家版本*/
    private String versionSign;

    /**
     * owner AE
     */
    private Long ownerAeId;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getMerchantName() {
        return merchantName;
    }

    public void setMerchantName(String merchantName) {
        this.merchantName = merchantName;
    }

    public String getContactName() {
        return contactName;
    }

    public void setContactName(String contactName) {
        this.contactName = contactName;
    }

    public String getContactMobile() {
        return contactMobile;
    }

    public void setContactMobile(String contactMobile) {
        this.contactMobile = contactMobile;
    }

    public String getAddress() {
        return address;
    }

    public void setAddress(String address) {
        this.address = address;
    }

    public String getEmail() {
        return email;
    }

    public void setEmail(String email) {
        this.email = email;
    }

    public String getDelivery() {
        return delivery;
    }

    public void setDelivery(String delivery) {
        this.delivery = delivery;
    }

    public String getCustomerServiceName() {
        return customerServiceName;
    }

    public void setCustomerServiceName(String customerServiceName) {
        this.customerServiceName = customerServiceName;
    }

    public String getCustomerServiceMobile() {
        return customerServiceMobile;
    }

    public void setCustomerServiceMobile(String customerServiceMobile) {
        this.customerServiceMobile = customerServiceMobile;
    }

    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }

    public Integer getPayload() {
        return payload;
    }

    public void setPayload(Integer payload) {
        this.payload = payload;
    }

    public Boolean getDeleted() {
        return deleted;
    }

    public void setDeleted(Boolean deleted) {
        this.deleted = deleted;
    }

    public Long getGmtCreator() {
        return gmtCreator;
    }

    public void setGmtCreator(Long gmtCreator) {
        this.gmtCreator = gmtCreator;
    }

    public Long getGmtModifier() {
        return gmtModifier;
    }

    public void setGmtModifier(Long gmtModifier) {
        this.gmtModifier = gmtModifier;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public String getVersionSign() {
        return versionSign;
    }

    public void setVersionSign(String versionSign) {
        this.versionSign = versionSign;
    }

    public Long getOwnerAeId() {
        return ownerAeId;
    }

    public void setOwnerAeId(Long ownerAeId) {
        this.ownerAeId = ownerAeId;
    }
}

==> qiho-center-api-2.6.8-20200914.022022-1-sources.jar: com/qiho/center/api/dto/merchant/MerchantDto.java <==
package com.qiho.center.api.dto.merchant;/**
 * Created by Administrator on 2017/11/15 0015.
 */

import com.qiho.center.api.dto.BaseDto;

import java.util.Date;

/** 商家实体
 * @author chensong
 * @create 2017-11-15 11:23
 **/
public class MerchantDto extends BaseDto{

    /** 主键Id */
    private Long id;

    /** 商家名称 */
    private String merchantName;

    /** 联系人姓名 */
    private String contactName;

    /** 联系方式 */
    private String contactMobile;

    /** 联系地址 */
    private String address;

    /** 邮箱 */
    private String email;

    /** 发货方式 */
    private String delivery;

    /** 客服姓名 */
    private String customerServiceName;

    /** 客服联系方式 */
    private String customerServiceMobile;

    /** 备注 */
    private String remark;

    /** 权重，排序值 */
    private Integer payload;

    /** 删除标识，true-删除/false-未删除 */
    private Boolean deleted;

    /** 创建人ID */
    private Long gmtCreator;

    /** 修改人ID */
    private Long gmtModifier;

    /** 创建时间 */
    private Date gmtCreate;

    /** 修改时间 */
    private Date gmtModified;

    /** 商家版本*/
    private String versionSign;

    /**
     * owner AE
     */
    private Long ownerAeId;

    /**
     * 审核状态
     */
    private int auditState;

    /**
     * 拒绝原因
     */
    private String reason;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getMerchantName() {
        return merchantName;
    }

    public void setMerchantName(String merchantName) {
        this.merchantName = merchantName;
    }

    public String getContactName() {
        return contactName;
    }

    public void setContactName(String contactName) {
        this.contactName = contactName;
    }

    public String getContactMobile() {
        return contactMobile;
    }

    public void setContactMobile(String contactMobile) {
        this.contactMobile = contactMobile;
    }

    public String getAddress() {
        return address;
    }

    public void setAddress(String address) {
        this.address = address;
    }

    public String getEmail() {
        return email;
    }

    public void setEmail(String email) {
        this.email = email;
    }

    public String getDelivery() {
        return delivery;
    }

    public void setDelivery(String delivery) {
        this.delivery = delivery;
    }

    public String getCustomerServiceName() {
        return customerServiceName;
    }

    public void setCustomerServiceName(String customerServiceName) {
        this.customerServiceName = customerServiceName;
    }

    public String getCustomerServiceMobile() {
        return customerServiceMobile;
    }

    public void setCustomerServiceMobile(String customerServiceMobile) {
        this.customerServiceMobile = customerServiceMobile;
    }

    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }

    public Integer getPayload() {
        return payload;
    }

    public void setPayload(Integer payload) {
        this.payload = payload;
    }

    public Boolean getDeleted() {
        return deleted;
    }

    public void setDeleted(Boolean deleted) {
        this.deleted = deleted;
    }

    public Long getGmtCreator() {
        return gmtCreator;
    }

    public void setGmtCreator(Long gmtCreator) {
        this.gmtCreator = gmtCreator;
    }

    public Long getGmtModifier() {
        return gmtModifier;
    }

    public void setGmtModifier(Long gmtModifier) {
        this.gmtModifier = gmtModifier;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public String getVersionSign() {
        return versionSign;
    }

    public void setVersionSign(String versionSign) {
        this.versionSign = versionSign;
    }

    public Long getOwnerAeId() {
        return ownerAeId;
    }

    public void setOwnerAeId(Long ownerAeId) {
        this.ownerAeId = ownerAeId;
    }

    public int getAuditState() {
        return auditState;
    }

    public void setAuditState(int auditState) {
        this.auditState = auditState;
    }

    public String getReason() {
        return reason;
    }

    public void setReason(String reason) {
        this.reason = reason;
    }
}
